class AuthenticationIds(object):
    ThreeDSecureVisaFullAuthentication = "fake-three-d-secure-visa-full-authentication-id"
    ThreeDSecureVisaLookupTimeout = "fake-three-d-secure-visa-lookup-timeout-id"
    ThreeDSecureVisaFailedSignature = "fake-three-d-secure-visa-failed-signature-id"
    ThreeDSecureVisaFailedAuthentication = "fake-three-d-secure-visa-failed-authentication-id"
    ThreeDSecureVisaAttemptsNonParticipating = "fake-three-d-secure-visa-attempts-non-participating-id"
    ThreeDSecureVisaNoteEnrolled = "fake-three-d-secure-visa-not-enrolled-id"
    ThreeDSecureVisaUnavailable = "fake-three-d-secure-visa-unavailable-id"
    ThreeDSecureVisaMPILookupError = "fake-three-d-secure-visa-mpi-lookup-error-id"
    ThreeDSecureVisaMPIAuthenticateError = "fake-three-d-secure-visa-mpi-authenticate-error-id"
    ThreeDSecureVisaAuthenticationUnavailable = "fake-three-d-secure-visa-authentication-unavailable-id"
    ThreeDSecureVisaBypassedAuthentication = "fake-three-d-secure-visa-bypassed-authentication-id"
    ThreeDSecureTwoVisaSuccessfulFrictionlessAuthentication = "fake-three-d-secure-two-visa-successful-frictionless-authentication-id"
    ThreeDSecureTwoVisaSuccessfulStepUpAuthentication = "fake-three-d-secure-two-visa-successful-step-up-authentication-id"
    ThreeDSecureTwoVisaErrorOnLookup = "fake-three-d-secure-two-visa-error-on-lookup-id"
    ThreeDSecureTwoVisaTimeoutOnLookup = "fake-three-d-secure-two-visa-timeout-on-lookup-id"
